Package: stringx
Type: Package
Title: Replacements for Base String Functions Powered by 'stringi'
Version: 0.2.9
Date: 2025-01-11
Authors@R: c(
    person("Marek", "Gagolewski",
        role = c("aut", "cre", "cph"),
        email = "marek@gagolewski.com",
        comment = c(ORCID = "0000-0003-0637-6028"))
    )
Description: English is the native language for only 5% of the World population.
    Also, only 17% of us can understand this text. Moreover, the Latin alphabet
    is the main one for merely 36% of the total.
    The early computer era, now a very long time ago, was dominated by the US.
    Due to the proliferation of the internet, smartphones, social media, and
    other technologies and communication platforms, this is no longer the case.
    This package replaces base R string functions (such as grep(),
    tolower(), sprintf(), and strptime()) with ones that fully
    support the Unicode standards related to natural language and
    date-time processing. It also fixes some long-standing inconsistencies,
    and introduces some new, useful features.
    Thanks to 'ICU' (International Components for Unicode) and 'stringi',
    they are fast, reliable, and portable across different platforms.
BugReports: https://github.com/gagolews/stringx/issues
URL: https://stringx.gagolewski.com/,
        https://github.com/gagolews/stringx
License: GPL (>= 2)
Depends: R (>= 4.1.0)
Imports: stringi (>= 1.7.2)
Suggests: realtest (>= 0.2.1)
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-01-11 16:25:27 UTC; gagolews
Author: Marek Gagolewski [aut, cre, cph]
    (<https://orcid.org/0000-0003-0637-6028>)
Maintainer: Marek Gagolewski <marek@gagolewski.com>
Repository: CRAN
Date/Publication: 2025-01-11 17:00:02 UTC
Built: R 4.6.0; ; 2026-04-27 04:07:49 UTC; unix
