S3method(as.POSIXxt,default)
S3method(as.POSIXxt,character)
S3method(as.POSIXxt,Date)
S3method(as.POSIXxt,POSIXt)
S3method(as.POSIXlt,POSIXxt)
S3method(as.Date,POSIXxt)
S3method(format,POSIXxt)
S3method(c,POSIXxt)
S3method(rep,POSIXxt)
S3method(seq,POSIXxt)
S3method(Ops,POSIXxt)
S3method(sort,character)
S3method(xtfrm,character)
S3method(xtfrm,default)
S3method(xtfrm2,character)
S3method(xtfrm2,default)
export(is.POSIXxt)
export(as.POSIXxt)
export(as.POSIXxt.Date)
export(as.POSIXxt.character)
export(as.POSIXxt.default)
export(as.POSIXxt.POSIXt)
export(as.POSIXlt.POSIXxt)
export(as.Date.POSIXxt)
export(c.POSIXxt)
export(rep.POSIXxt)
export(seq.POSIXxt)
export(format.POSIXxt)
export(Ops.POSIXxt)
export(Sys.time)
export("%x!=%")
export("%x*%")
export("%x+%")
export("%x<%")
export("%x<=%")
export("%x==%")
export("%x>%")
export("%x>=%")
export(LETTERS_BB)
export(LETTERS_BF)
export(LETTERS_CAL)
export(LETTERS_FRAK)
export(LETTERS_GREEK)
export(casefold)
export(chartr)
export(chartr2)
export(digits_dec)
export(digits_hex)
export(endsWith)
export(letters_bb)
export(letters_bf)
export(letters_cal)
export(letters_frak)
export(letters_greek)
export(ISOdatetime)
export(ISOdate)
export(nchar)
export(nzchar)
export(paste)
export(paste0)
export(printf)
export(sprintf)
export(startsWith)
export(strcat)
export(strcoll)
export(strftime)
export(strptime)
export(strrep)
export(strsplit)
export(strtrans)
export(strtrim)
export(strwrap)
export(substr)
export(substrl)
export(substring)
export("substr<-")
export("substrl<-")
export("substring<-")
export(tolower)
export(toupper)
export(trimws)
export(xtfrm)
export(xtfrm2)
export(sort.character)
export(xtfrm.character)
export(xtfrm.default)
export(xtfrm2.character)
export(xtfrm2.default)
export(sub)
export(sub2)
export(gsub)
export(gsub2)
export(grep)
export(grepl)
export(grepl2)
export(grepv2)
export("grepv2<-")
export(regexpr)
export(regexpr2)
export(gregexpr)
export(gregexpr2)
export(regexec)
export(regexec2)
export(gregexec)
export(gregexec2)
export(gsubstrl)
export("gsubstrl<-")
export(gsubstr)
export("gsubstr<-")
export(regextr2)
export("regextr2<-")
export(gregextr2)
export("gregextr2<-")
